@@ -213,11 +213,17 @@ class SpellChecker {
       });
   }
 
+  protected _set_theme(name: string) {
+    document.body.setAttribute('data-jp-spellchecker-theme', name);
+  }
+
   update_settings(settings: ISettingRegistry.ISettings) {
     this.settings = settings;
     const tokens = settings.get('ignore').composite as Array<string>;
     this.ignored_tokens = new Set(tokens);
     this.accepted_types = settings.get('mimeTypes').composite as Array<string>;
+    const theme = settings.get('theme').composite as string;
+    this._set_theme(theme);
 
     // read the saved language setting
     const language_code = settings.get('language').composite;
@@ -493,6 +499,7 @@ class SpellChecker {
           if (stream.eatWhile(this.rx_word_char)) {
             const word = stream.current().replace(/(^')|('$)/g, '');
             if (
+              word !== '' &&
               !word.match(/^\d+$/) &&
               this.dictionary !== undefined &&
               !this.dictionary.check(word) &&
@@ -539,10 +546,8 @@ class SpellChecker {
     }).then(value => {
       if (value.value !== null) {
         this.language = languages.filter(l => l.name === value.value)[0];
-        this.load_dictionary().then(() => {
-          // save the chosen language in the settings
-          this.settings.set('language', this.language.code).catch(console.warn);
-        });
+        // the setup routine will load the dirctionary
+        this.settings.set('language', this.language.code).catch(console.warn);
       }
     });
   }
